package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#``@````!````````'```````````0```````
M`*@0(```!P!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0```````"?
M0````````)]`````````GT``````````'``````````<``````````%P```#
M````!`````````(X`````````C@````````".``````````8`````````!@`
M````````"`````$````%````````````````````````````````````````
MGUP```````"?7````````0```````0````8```````"?W````````9_<````
M```!G]P````````#S````````!1$```````!```````"````!`````````-H
M`````````V@````````#:`````````(``````````@``````````"&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````"?W````````9_<```````!G]P`````````
M)``````````D``````````$`````````````````````````````````````
M````````````````````````````````````"````P`"```#````````````
M```!``````$H````````\@`#\@`````````````````````````````````"
M(%`!*````````+```````````````````````````````````````B!0`2@`
M``````"R#P`\``````````````````````````````````(@4`$H````````
M\O\'_``````````````````````````````````"(%`!*````````+,___P`
M`````````````````````````````````B!0`2@```````"R`P`,````````
M``````````````````````````(@4`$H````````L```````````````````
M```````````````````"(%```````````0````````-"``````````$`````
M```#30`````````/````````!*``````````#````````!@X``````````T`
M``````!@@``````````$````````!6@`````````!0```````!+(````````
M``8````````(J``````````*````````!+X`````````"P`````````8````
M`'```#4```````&<2``````````5`````````````````````P```````:!@
M`````````!$````````7B``````````2`````````(``````````$P``````
M```0`````'````$``````````0````!P```%``````````(`````<```!@``
M`````````````'````H`````````(`````!P```1`````````&P`````<```
M$@`````````9`````'```!,`````````)``````````8````````````````
M;___^P`````(```!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````&$```!L````
M```````````4````5```````````````6@``````````````*P```#@`````
M````/0```%X````;`````````$8````"````"0```#0````?````"````#$`
M``````````````````!7````(@```#L``````````````!,````D````2```
M````````````'0```#8````J````)P`````````O````/@```#<````6````
M'@```"P`````````/P```!<`````````20```$,`````````3@````\````E
M````9@```"@``````````````$(`````````2P```&`````1````````````
M```P````.@````````!-````)@```#D````````````````````8````(P``
M`!4````@````&0```%@`````````+@````,````````````````````:````
M`````"T````2`````````&L````I````,@``````````````````````````
M````:0``````````````!@``````````````70````````!C````````````
M``````````````````!?`````````$<```!;````$````%````!5````````
M````````````#@````P`````````-0```!P```!!````80````L`````````
M(0```%,```!`````,P`````````'````40``````````````9```````````
M`````````&<````\``````````T``````````````$0```!*````3P``````
M``````````````````!,````10```&H```````````````4`````````````
M`%(``````````````&@```!6`````````````````````````%P```!9````
M"@````````````````````````!B````!````&4`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````P``"```
M`````!@X``````````````,S$@``"0```````!D``````````EP```1&$```
M"0```````!D```````````````1-$@``"0```````!T``````````$@```.7
M$@``"0```````"ZX`````````$@````J$@``"P```````&"```````````@`
M``,Y(0````````````````````````````.!$@``"0```````";H````````
M`4@```16$@``"0```````"@P`````````!@```1G$@``"0```````!P(````
M``````````.R$@``"0```````"\``````````10```0*$@``"0```````#`4
M````````")@```/B$@``"````````!@X``````````@````!$P#_\0``````
M```!``````````````-C$@``"0```````"80`````````%@```1S$@``"0``
M`````!P```````````````1[$```%0```````:.H``````````````/$$@``
M"0```````"Y$`````````'0```-K$@``"0```````#BL````````!)@```/H
M$@``"0```````%A\`````````<````,X$0``````````````````````````
M``0P$0``$0```````:!```````````@```1T$@``"0```````!P`````````
M``````0C$@``"0```````"JD`````````"P```2!$```$0```````:``````
M``````````2($```%0```````:.H``````````````/?$@``"0```````%?T
M`````````(@```07$@``"0```````"K0`````````40```/]$@``"0``````
M`"P4`````````C`````2$0``$@```````:!0``````````````24$```%```
M`````:.H``````````````/2$@``"0```````"A(`````````EP```/S$@``
M"0```````%H\`````````A````2;$```%0```````;0@``````````````0Z
M$@``"0```````#U$`````````*P```"Y$@```````````&!@````````````
M``#`$@```````````&!0``````````````#1$@```````````&!`````````
M``````#8$@```````````&`P``````````````"O$@```````````&`@````
M``````````#J$@```````````&`0``````````````,/$@```````````&``
M``````````````#Q$@```````````%_P``````````````,!$@``````````
M`%_@``````````````$%$@```````````%_0``````````````"<$@``````
M``````````````````````(,$@```````````%_```````````````"T$@``
M`````````%^P``````````````$0$@```````````%^@``````````````$6
M$@```````````%^0``````````````"+$@``````````````````````````
M``![$@````````````````````````````$G$@```````````%^`````````
M``````!L$@```````````%]P``````````````$M$@```````````%]@````
M``````````$R$@```````````%]0``````````````%%(```````````````
M``````````````%?$@```````````%]```````````````!C$@``````````
M`%\P``````````````+Q$@```````````%\@``````````````%E$@``````
M`````%\0``````````````%J(@````````````````````````````&`(@``
M``````````````````````````!4$@```````````%\```````````````&/
M$0````````````````````````````+Y$@```````````%[P````````````
M``&A$@```````````%[@``````````````,Z$0``````````````````````
M``````,F$@```````````%[0``````````````!&$@```````````%[`````
M``````````.I$@```````````%ZP``````````````&J$@```````````%Z@
M``````````````&X$@```````````%Z0``````````````&_$@``````````
M`%Z````````````````[$@```````````%YP``````````````'/$0``````
M``````````````````````':$@```````````%Y@``````````````'A$@``
M`````````%Y0``````````````,($@```````````%Y```````````````'F
M(`````````````````````````````("$@```````````%XP````````````
M``(+$@```````````%X@```````````````P$@```````````%X0````````
M``````(1$@```````````%X```````````````(9$@```````````%WP````
M``````````$^$@```````````%W@``````````````(A$@```````````%W0
M``````````````(H$@```````````%W```````````````(T$@``````````
M`%VP``````````````([$@```````````%V@``````````````,7$@``````
M`````%V0``````````````+I$@```````````%V```````````````))$@``
M`````````%UP``````````````)0$@```````````%U@``````````````)7
M$@```````````%U0``````````````)=(@``````````````````````````
M``)U$@```````````%U```````````````**$@```````````%TP````````
M``````*;$@```````````%T@``````````````*D$@```````````%T0````
M``````````*K$@```````````%T```````````````*W$@```````````%SP
M```````````````<$@```````````%S@``````````````*_$0``````````
M``````````````````+,$0````````````````````````````+3$@``````
M`````%S0``````````````+A$@```````````%S`````````````7T193D%-
M24-?3$E.2TE.1P!?7U),1%]-05``4&5R;%]S>7-?=&5R;0!?9FEN:0!P97)L
M7W!A<G-E`'!E<FQ?86QL;V,`<&5R;%]D97-T<G5C=`!097)L7W-Y<U]I;FET
M,P!P97)L7W)U;@!P97)L7V-O;G-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`4&5R
M;%]A=&9O<FM?;&]C:P!097)L7V%T9F]R:U]U;FQO8VL`<&5R;%]F<F5E`&=E
M='5I9`!?7W-T86-K7V-H:U]F86EL`'-T<FQE;@!097)L7W-V7S)P=E]F;&%G
M<P!M96UC<'D`<'1H<F5A9%]G971S<&5C:69I8P!097)L7VYE=UA3`&UK9&ER
M`%]?97)R;F]?;&]C871I;VX`<FUD:7(`<F5A9`!097)L7W-A9F5S>7-M86QL
M;V,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!C;&]S90!E>&ET`%]?<F5G
M:7-T97)?9G)A;65?:6YF;P!?7V-X85]F:6YA;&EZ90!?7W-T86-K7V-H:U]G
M=6%R9`!R96%D;&EN:P!097)L7W-V7W-E='!V`'-T<F-H<@!097)L7V=V7V9E
M=&-H<'8`4$Q?=&AR7VME>0!S=')S='(`;W!E;@!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`8VQO<V5D:7(`;'-T870`<W1R;F-M<`!M96UM;W9E`'5N
M;&EN:P!097)L7VUG7W-E=`!M96US970`4&5R;%]A=E]F971C:`!S=')C;7``
M9V5T<&ED`&QS965K`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?;F5W6%-?9FQA9W,`<VYP<FEN=&8`86-C97-S
M`%!E<FQ?9V5T7W-V`')E86QL;V,`4$Q?9&]?=6YD=6UP`'-T9&5R<@!097)L
M7V%V7W-H:69T`&]P96YD:7(`<F5A9&1I<@!F<')I;G1F`'-T<FYC<'D`<W1R
M=&]K`'-T<F1U<`!S<')I;G1F`'!T:')E861?871F;W)K`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UM:7!S-C0N
M<V\N,0!X<U]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9FEN9'!R;V<`<VAA7VEN
M:70`<VAA7W5P9&%T90!S:&%?9FEN86P`<&%R7VEN:71?96YV`'!A<E]M:W1M
M<&1I<@!P87)?9&ER;F%M90!P87)?8F%S96YA;64`;7E?<&%R7W!L`'!A<E]C
M;&5A;G5P`%]F=&5X=`!?<W1A<G1?8P!P87)?8W5R<F5N=%]E>&5C`%]S=&%R
M=%]D871A`%]?<W1A<G0`7V9B<W,`7V9D871A`%]?8G-S7W-T87)T`%]E9&%T
M80!?96YD`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%````````````
M`````````````````````:``````````$@,```````&@"````````!(#````
M```!H!`````````2`P```````:`8````````$@,```````&@(````````!(#
M```````!H$`````````2`P```````:.@````````$@,`````````````````
M``````````````````````````````````````````````!GO?_@_[P`$/^_
M`!@`````!!$``0`````#@!`E/!P``B><"``#G^`MWYF`:`,@^`D`````!!$`
M`0`````#@!`E/!P``B><!]P#G^`MWYF`^`,@^`D`````W[P`$-^_`!@#X``(
M9[T`(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&>]_[#_O`!`/!P``@.9X"UGG`=0WYF!\/^E`!#_I@`(KZ0`
M'&>F``AGI0`09Z0`'/^_`$C_L``@_[,`./^R`#`#(/@)_[$`*-^&@6#?A(&(
MWYF"R`#`*"4#(/@)WY""4-^"@S"00@``%$``$]^9@4C?F8)(`R#X"0``````
M0"`EWX*`.!2```3\1+00WYF!V`,@^`DD!``!WYF!H`,@^`D`````WYF!2`,@
M^`F.!```H$`*H=^9@4@#(/@)C@0``(X$``"00P3RWYF!2#1C``(#(/@)H$,$
M\H^D`!R00P3R)(0`!=^9@;`T8P`!``0@^`,@^`F@0P3RWZ4`$`!`."7?@H`X
M)`,`!/Q'L_C<H@``CZ8`'/SB``#?@H!89$)D@/SB``C?@H#HW$(``/SB`!#?
M@H!89$)DB/SB`!C?@H`XK$.T````&"5D8P`!``,0``!&("H4@``Z``,@^-^1
M@#@DP@`#WX6`6-^9@HC>)+00``(0^`#B$"T``$`E),8``V2E)F@#(/@)_$``
M`!1```4`0(`EWYF!R`,@^`G>)+00`$"`)=^9@B#>)+00`R#X"=^3@%C?A(!8
M9G,@+`)@R"4#(/@)9(1AX!1```_?F8$PWY*`.-Y"M`@40``%WX2`6`)@R"4#
M(/@)9(1A:/Y"M`C>1+0($(```]^9@/`#(/@)`````-^9@3`#(/@)WB2T$-^9
M@R@#(/@)`````-^_`$C?O`!`W[,`.-^R`##?L0`H`@`0)=^P`"`#X``(9[T`
M4`"D("TD0@`#W(0````"$/@`XA`M$`#_O/Q$````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````01``<``/`E_______]^[C_______W\L/_______>,8
MW_P```/\X"\#H"`EW^4`$`"\*"W?^0`(`SS(+20!__`#H>@D`R#X"0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!G
MO?_P_[P``#P<``(#F>`M9YP#4-^9@AC?B(`@WX>`*(R%``1DA@`(WX2`,/^_
M``@#(/@)``!()=^_``C?O````^``"&>]`!```````````#P#``(`>1@M9&,#
M`-QD@#C<8H!`9(2@6!!$``7<>8)P$R```P`````#(``(``````/@``@`````
M/`,``@!Y&"UD8P+(W&2`.-QE@$!DA*!8`*0H+P`%$/L`!2_^`*(H+0`%*'L0
MH``%W'F!N!,@``,``````R``"``````#X``(``````````!GO?_0_[P`(#P<
M``(#F>`M9YP">/^S`!C?DX`X_[\`*))BH[#_L@`0_[$`"!1``"O_L```WX*!
MZ!!```3?@H!(WYF!Z`,@^`G<1```WX.`.-^1@%!D8Y_PWY"`.`(CB"_>`J.X
M`!&(^]^$@#AF,?__`%$8*V22G_`08``-WYF`6&1"``$```````(8^`)#&"W<
M>0```R#X"?X"H[C>`J.X`%$8*Q1@__AD0@`!WYF`6&<Y'5`#(/@)`````-^"
M@O`00``$WYF"\-^$@#@#(/@)9(2?W"0"``&B8J.PW[\`*-^\`"#?LP`8W[(`
M$-^Q``C?L````^``"&>]`#``````9[W_\/^\```\'``"`YG@+6><`7C?@H'@
M$$``!_^_``C?A8`XWX2`.-^9@>!DI:/``R#X"62$G]S?F8!8W[\`"-^\``!G
M.1V(`R``"&>]`!```````````&>]_[#_O`!`/!P``@.9X"W_L0`0_[\`2/^V
M`#C_M0`P_[0`*/^S`"#_L@`8_[``"&><`2`0@``?``"()=^"@A#<5```$H``
M&P"`F"4`H*@E`(`P)20#`#V`P@``%$``(0#3@"\`$(```H"0)206`#W>40``
M$B``#]^9@I`"`#`E`F`H)0,@^`D"("`E%$``&0(P$"V`0@``%%8`%@`````"
M5)`O`!*0^V80``&NL@```C"(+=^_`$C?O`!`W[8`.-^U`##?M``HW[,`(-^R
M`!C?L``(`B`0)=^Q`!`#X``(9[T`4!!#_]\`````$`#_VF3&``$0`/_>9E(`
M"&>]_]#_O``@/!P``@.9X"UGG``D_[``&-^9@%C?D('X_[\`*-X"``!GI0`$
M9SD?,/^B``@#(/@)`````-^D``C>`P``$(,`!-^_`"C?F8$8`R#X"0````#?
MO``@W[``&`/@``AGO0`P9[W_L/^\`$`\'``"`YG@+6><_[S_L0`HWY&!^/^S
M`#C_L@`P_[``(/^_`$C>(@``WY"`6-^3@A#_H@`89[(`%&80'S`"0"@E`@#(
M)0,@^`G_I``(%$``"-^D``C?HP`8WB(``!!B``W?OP!(WYF!&`,@^`D`````
MCZ(`%``"&/C>8@```$,0+=Q#``@08/_M_$,``!``__QD0@`(W[P`0-^S`#C?
ML@`PW[$`*-^P`"`#X``(9[T`4&>]_L#_O`$P/!P``@.9X"UGG/\$_[4!&-^5
M@?C_OP$X_[<!*/^V`2#_M`$0_[,!"/^R`0#_L0#X_[``\-ZB``#_H@#H$(``
M&0````"`@@``$$``%@"`B"7?F8-(`R#X"0`````00``1`$"0)=^3@%C?E(!8
MWY:`6&9S80!FE"%,WYF"T`,@^`D"0"`E%$``#M^9@MC?F8)X`R#X"0)`("7?
MF8&8`R#X"0(@("7?HP#HWJ(``!!B`#W?OP$XWYF!&`,@^`D`````9%``$P)@
M*"4#(/@)`@`@)1!`_^K?F8+0WYF"V&;%80@#(/@)`@`@)1!`_^3?F8+0WYF!
M(`,@^`D"("`EWYF!(`(`("4#(/@)`$"X)=^9@J`"XA`M``(@``,@^`DDA``"
MWX6`6-^9@4``0"`E`@`X)0(@,"5DI6$0`R#X"?^B``C?I``(WYF!:`,@^`EG
MI0`8)`/__Q!B``[?I``(CZ(`."0#0``P0O``%$,`"0`````"@,@E`R#X"0``
M``#?F8%P`R#X"=^D``@0`/^\WYF"T-^9@J@#(/@)_Z0`"!``__<`````W[P!
M,-^W`2C?M@$@W[4!&-^T`1#?LP$(W[(!`-^Q`/C?L`#P`^``"&>]`4!GO?\`
M_[P`\#P<``(#F>`M9YS]+/^Q`.C?D8'X_[``X-^9@H#_OP#XWB(``&>E``@`
M@(`E_Z(`V`,@^`D`````%$``%(^C`"@D!4``,&/P`!!E``0`8"`E-`.@`!2#
M``8`````WYF#$"0%``(#(/@)`@`@)2Q"``'?I`#8WB,``!"#``;?OP#XWYF!
M&`,@^`D`````$`#_^```$"7?O`#PW[$`Z-^P`.`#X``(9[T!`&>]_Z#_O`!0
M/!P``@.9X"UGG/Q\_[,`,-^3@?C_L0`@_[``&/^_`%C_M@!(_[4`0/^T`#C_
ML@`HWF(``("C``#_H@`()`(`/0"`B"448@`"`*"`)62P``'?F8$@`R#X"0(`
M("7?F8!89Z4`!`(@("5G.1\P`R#X"0!`H"400``3`$"0)=^9@2`#(/@)`$`@
M)0!4$"L40``F`B`8)8("``!F$``!9E(``11`__RB0O__WZ,`"-YB```08@!6
MW[\`6-^9@1@#(/@)`````-^5@A```)`EWK8```+`$"7<0P``%&``/&1"``C?
M@H`X)D0``HQ#L_`08``Y``0@^-^9@R``@"@E`R#X"0+`("400/_H_J(``"9"
M``$``ACXWJ(```!#$"W\0```K[(`!`(@&"4D!``]@&(``!!```./L@`$%$0`
M,@````#?E8(0`'$8+]^9@J```Q@`9H0``@`2$/@`9"`MWK(```,@^`D"0I`M
M$$#_S_Y"``"/H@`$)`4`/0`"&/C>H@```$,0+=Q"``""(P``9C$``:!#````
M0"`E$&```V1"``$49?_Y`````"0#`#V@@P``@@,``&80``%D0@`!%&#__*!#
M__\0`/^X`````!``_\$F4@`!WYF"H"0#``$#(/@)K$.S\!!`_[``0"`EWYF"
MF``2,/@#(/@)`L`H)1``_\/^H@``$`#_R61C``'?O`!0W[8`2-^U`$#?M``X
MW[,`,-^R`"C?L0`@W[``&`/@``AGO0!@9[W_\/^\```\'``"`YG@+6><^D#?
M@H)0_[\`"-^9@4@#(/@)C$0``-^'@'#?A8!8WX:!D-^9@5ADYY\H9*5A&`,@
M^`D`0"`EW[\`"-^\```#X``(9[T`$&>]_^#_O``0/!P``@.9X"UGG/GH_[``
M"-^0@E#_OP`8WYF!2`,@^`F.!```WYF`>`,@^`D`0"`EWYF!2`,@^`F.!```
MWXB`6-^%@%C?AH"`WYF#`&4(9'@``$@E`0`X)62E83@#(/@)`$`@)=^_`!C?
MO``0W[``"`/@``AGO0`@9[W?H/^\(%`\'``"`YG@+6><^6C_LR!(WY.!^-^9
M@N#_OR!8_[(@0/^Q(#C_L"`PWF(``/^B("@#(/@)`````-^(@%C?AH!8WYF#
M"&>D`!AE"&%0`$`X)63&85@D!1`!`R#X"?^D``@D`___%$,`"=^D``@``"`E
MWZ,@*-YB```08@`IW[\@6-^9@1@#(/@)`````"Q#$`$$;```!$#_]=^9@@AG
ML1`@)`80``,@^`D"("@E``*```8`_^X"`)`EWYF"H`,@^`DF!``!$$#_Z0!`
M("4`41`K$$``!`(D$"L`DA`M`B(`,P(D$"L00``$WYF!.`(P$"T`@@`SWYF!
M.`(`,"4"("@E*E(0`@9,```#(/@)``````!0@"T`0"`E$`#_U:(```#?O"!0
MW[,@2-^R($#?L2`XW[`@,`"`$"4#X``(9[T@8#P#``(`>1@M9&/X(-QY@(@#
M(``(`````&>][K#_O!$X/!P``@.9X"UGG/@(_[<1,/^P$/C?EX'X`("`)=^9
M@%C?A(!8_[\12/^T$1C_LQ$0_[X10/^V$2C_M1$@_[(1"/^Q$0#>X@``9(1A
M:&<Y("P`H)@E_Z(0Z`,@^`D`````WYF"."0%`"\"`"`E`R#X"0!`H"400``.
MWYF!(-^$@%C?F8!8`@`H)6<Y(]0#(/@)9(1A>-^C$.C>X@``$&(`8-^_$4C?
MF8$8`R#X"0`````"`"`E`R#X"=^2@%C?F8%09D5AB`)@("4#(/@)``*(`-^5
M@%C?EH!8`$#P)=^"@%AFM6$`9M9AD/^B``@3P/_DWX2`6(/"```40``"````
M``*@\"42@``,WYF"V`/`*"4#(/@)`H`@)11```C?F8$@WYF!4&9%88@#(/@)
M```@)1``_^X`0/`EWYF!(`,@^`D#P"`E)`0`+P`"$``D0___`\,8+8!E```0
MI``4)$;__R8C``$`8A`A*$(0`!!`_\/?H@`(WYF#"&>S`.@"`$@E`L!`)0/`
M."5D1F&8)`40``,@^`D"8"`E)$(``2Q"$`$40``%WYF!:````#2@8```$`#_
MY@#`$"5GI0`8`R#X"0)@("440/_6CZ(`.#0#@``P0O``%$/_T]^9@5#?F8,0
M)`4``0,@^`D"8"`E%$#_S=^9@5#?A(!8WYF`6`)@*"5G.2/4`R#X"62$87C?
MF8)H`R#X"0)@("40`/^>`$"`)=^^$4#?O!$XW[<1,-^V$2C?M1$@W[01&-^S
M$1#?LA$(W[$1``(`$"7?L!#X`^``"&>]$5``@!`E)`4`+X"#```48``#````
M``/@``@`````%&7_^F2$``$0`/_X`(`0)6>]_^#_O``0/!P``@.9X"W_OP`8
M_[``"!"```1GG/6`@((``!1```L`@(`EWX2`6-^9@FADA&$``R#X"0````#?
MOP`8W[P`$-^P``@#X``(9[T`(-^9@2`#(/@)`````"0#`"]D0O__`@(0+0("
M("L0@``H`````(!$```0@P`A`````"0#`"\"`B`K$(``(0````"`1```%(,`
M'&1%__\D`P`O9$+__P("("L0@``&`%`P+X!$```0@__[9$+__V1"``$`4#`O
M9,,``BQC$`$08/_;```0)0(`*"7?D(`XWYF"`&3&``%F!*/P+,(0`01,```#
M(/@)`````!``_]!F`J/P$`#_V61"__\0`/_>`*`0)18"_^,D`P`O@@,``"0"
M`"\48@`$WYF":-^$@%@0`/_!9(1A`-^$@%@0`/^^9(1AD&>]_X#_O`!P/!P`
M`@.9X"UGG/0\_[4`8-^%@'#?E8'X_[\`>-^9@3C_M@!H_[0`6/^S`%#_L@!(
M_[$`0/^P`#@D!@`B9*6?`-ZB```#H"`EWY"`6/^B`"@#(/@)9A`@E-^$@%@"
M`,@E9(1AH`,@^`G?DX!8WX2`6`(`R"5DA&&P`R#X"=^4@%C?A(!8`@#()62$
M8;@#(/@)WY*`6-^$@%@"`,@E9(1AR`,@^`G?EH!8`@#()69D8=`#(/@)WY&`
M6-^$@%@"`,@E9(1AX`,@^`EF,2`L`@#()0,@^`EFA&%H`@#()0,@^`EF1&'P
M`@#()0,@^`EFQ&(`WX2`6`(`R"4#(/@)9(1B$-^$@%@"`,@E9(1A>`,@^`G?
MD(!8WX2`6`(@R"5DA&(@`R#X"680(]000``$`@#()0!`*"4#(/@)9L1B`-^$
M@%@"(,@E`R#X"62$8C@00``%`$`H)=^$@%@"`,@E`R#X"62$8-#?A(!8`B#(
M)0,@^`EDA&)09H1A:!1```@`0"@EWX2`6`(@R"4#(/@)9(1B8!!``!$`0"@E
M9D1A\`(`R"4#(/@)`````-^%@%AF9&'0`@#()0,@^`EDI6*(WZ,`*-ZB```0
M8@`.W[\`>-^9@1@#(/@)`````-^%@%C?F8*0)`8`"F2E8G@#(/@)9Z0`$11`
M_^UGI0`;$`#_Z&9$8?#?O`!PW[8`:-^U`&#?M`!8W[,`4-^R`$C?L0!`W[``
M.`/@``AGO0"`9[W_X/^\`!`\'``"`YG@+6><\@S_L``(WY"`."0"__^.`Z`P
M%&(`#?^_`!C?A(!8WYF`6&<Y("P#(/@)9(1A\!!```4``!@E@$(``!!```(X
M0@`P``(8*ZX#H##?OP`8C@*@,-^\`!#?L``(`^``"&>]`"!GO?_P_[P``#P<
M``(#F>`M9YSQF-^9@1#_OP`(`R#X"0````#?F8(H`R#X"0!`("400``"W[\`
M"-Q"``#?O````^``"&>]`!!GO?_0_[P`(#P<``(#F>`M9YSQ4/^S`!C?F8!8
MWY.`6/^Q``AG.2`L`("()69D8I#_OP`H_[(`$`,@^`G_L````F`@)1!```4"
M("@E`$"`)8!"```40``,WYF"6&2$8I#?F8!8W[\`*-^\`"#?LP`8W[(`$-^Q
M``C?L```9SDCU`,@``AGO0`P`R#X"0(`("440``9W[\`*-^9@2`#(/@)`B`@
M)=^9@2`"`"`E`R#X"0!`D"7?F8*@`D(0+0,@^`ED1``"WX>`6-^%@%C?F8%`
M9*5AF`!`("4"`$`E9.=AB`(@,"4#(/@)`$"0)0)`*"40`/_;9F1BD-^\`"#?
MLP`8W[(`$-^Q``C?L````^``"&>]`#!GO8`0_[Q_V#P<``(#F>`M9YSP//^W
M?]#?EX'X_[]_Z/^V?\C_M7_`_[1_N/^P?YC_OG_@_[-_L/^R?ZC_L7^@9[W^
M``"`J"5GI``0WN(``#0#@7@`9!@M_&(``#0"@8``1!`M/!#__P!0@"W?@H!8
MWX6`.&1"8JC^`GZ`WX*`6-^9@3AD0F$`)`8`,&2EH`!F!'ZP_@)^B`,@^`G^
M`'Z0WX*`6-^6@%AD0F*P_@)^F-^4@%C?@H!89M8@+&1"8KAFA&%H`L#()?X"
M?J`#(/@)_@!^J!!``!;?F8"0`$"`)8!"```00``2`````-^9@)@#(/@)`@`@
M)=^9@F@#(/@)`@`@)0!`@"5GHP`0-`*!>`!#$"W<0P``WN(``!!B`=`"`!`E
MWYF!&`,@^`D``````R#X"0`````40``:`$"`)3P1__\T`H&`9Z,`$&8Q?I@`
M0Q`M`%&(+=XD```4@``$`L#()=^0@%@0```.9A!BH`,@^`D`````%$```P!`
M("40`/_U9C$`"(!"```00/_\WYF":`,@^`D`````$$#_^`!`@"7?F8$@`@`@
M)0,@^`G?DX!8WYF"H``"('ADA``!`R#X"69S8L@`0)`E`$"()8(&```4P`!;
MWYF!0-^3@%@\$?__-`*!@&>C`!!F,7ZP`$,0+0!1B"UF<R,DWC```!(``!`"
MP,@E`R#X"0(`("400`!3`$"`)8!"```00`!0`F#()0,@^`D"`"`E$$#_\V8Q
M``C?F8)H`R#X"0(`("4`0(`EWYZ`6#P1__\T`H&`9Z,`$&8Q?H``0Q`M`%&(
M+6?>(R06```(WYF!(-XS```28``%`````()B```40``Z`\#()=^9@2`#(/@)
M`@`@)=^9@2`"0"`E`R#X"0!`B"7?F8*@`B(@+0`$(``DG@0$`R#X"0/`("4"
M0$@EWXB`6-^2@%C?A8!8WYF!0&4(8M!F1V&0`@`P)62E8M@`0"`E`R#X"0!`
MB"7?F8%X)`4!P`,@^`D"("`E)`/__Q1B`"/?F8&``R#X"0````",2```)`(`
M$1$"`!YGHP`0WX*#.-^%@%C>I@``W$0``-^9@=`"(#@E`R#X"62E8N@0`/]R
M``"`)0(@("4PQ@#_`F`H)0,@^`EF$``!$`#_G68Q``(0`/^F9C$`"`,@^`D"
M8"`E$$``!-^9@F@#(/@)`F`@)0!`@"40`/^W9C$`"&>C`!`\$/__-`*!@-^9
M@H``0Q`M9@5^X`!%*"T#(/@)`B`@)1!```L`0)@EWX*#.-^%@%C>I@``W$0`
M`-^9@=`"(#@E`R#X"62E8R@0`/_8`````&>C`!`T`H&``$,0+0!0@"V.`G\`
M)`-``#!"\``40__OWX*#.-^9@1".`W\(`R#X"?^C``C?HP`(``(0`!1B_^??
M@H,XC@)_`"0#`<`P0@'_%$/_XM^"@SC?F8*@`R#X"0/`("7?A(!8`L#()62$
M8X`#(/@)`$"`)11``'\`0"`EWK8``-^9@2`#(/@)`L`@)0`"$```0/`E*$(`
M!!1``"/?F8"@WX6`6-^9@MAGQ/_\9*5CB`,@^`D"Q"`M%$``&]^9@*`D`@`$
M$\(`!B?>__L"WO`M@\,``"0"`"\48@`3`````-ZU``@2H``/WYF!(`,@^`D"
MH"`E+$,`!!1@``O?F8"@WX6`6-^9@MAD0O_\9*5CD`,@^`D"HB`M%$```]^9
M@*`"H+`EWYF`H`,@^`D`````%$``HM^%@%C?F8)@```H)0,@^`D"P"`E$$``
MFP!`J"7?F8+H)`8``B0%_^X`0"`E`R#X"3P3__]GHP`0-`*!@`!#$"UF=G_X
M`%:P+=^9@:@D!@`&`L`H)0,@^`D"H"`E9Z,`$#0"@8``0Q`M`%,0+9!#?_@4
M8``^WYF"Z)!#?_DD!`!#%&0`.P``,"6017_Z)`0`012D`#<`````D$1_^Q2#
M`#0D`P!(D$1__!2#`#(``"@ED$-__20"`$448@`N`````"0&``(D!?_&`R#X
M"0*@("7?F8&H)`8`*0+`*"4#(/@)`J`@)=^)@%@"P$`E92ED>-^%@%C?F8%`
M9D=AD`(@,"5DI6.8`R#X"0(`("7?F8%P`R#X"0(@("7?F8!8`@`H)6<Y(]0#
M(/@)9H1A:-^9@)@#(/@)`@`@)1``_JYGHP`0WYF":`,@^`G>M@``WYF`J`+`
M("4#(/@)`$`H)11`_WL`0+`E$`#_>=ZV`````#`E```H)0*@("4#(/@)/!/_
M_]^9@+`#(/@)9GY_^&>C`!``0+`E-`*!@`!#$"T`7O`MWYF!J#0&@``#P"@E
M`R#X"0*@("4``C``',``+=^9@+C?F8'``J`@)0,@^`EF<W^P9Z,`$#0"@8``
M0Q`M`%.H+=^9@,`"P"@E`J`@)0,@^`EF<P`8WX6`6#0"@8!GHP`0`$,0+0!3
MF"T``/`E/!;__V2E8L@"OA`MWYF!0)!&```"8"`E_Z4`"`,@^`EGW@`!)`,`
M%-^E``@7P__V9G,``F>C`!`T`H&``$,0+0!6$"W?B8!8H$!_\#0"@8!FR'_(
M`$,0+64I9'@0`/^A`$A`+0/`*"4#(/@)`L`@)1``_\G?F8&HWX6`6-^$@%C?
MF8!89*5BB&2$8?!G.2/4`R#X"=^5@%C?F8+@WY:`6`,@^`DD'O__WX6`6-^9
M@4!FJ61X`$!`)69'89`"(#`E9*5CJ`(`("5FM61X`R#X"6;68[C?F8%X)`4!
MP`,@^`D"`"`E%\+_AM^9@8`#(/@)`````"0#`!&,0@``%$/_@-^9@N`#(/@)
M`````-^9@4`F:0`!`J!0)0!`0"5F1V&0`B`P)0+`*"4"`"`E`R#X"0$@F"40
M`/_HWYF!>&>]`@#?OW_HW[Y_X-^\?]C?MW_0W[9_R-^U?\#?M'^XW[-_L-^R
M?ZC?L7^@W[!_F`/@``AGO7_P9[W_D/^\`%@\'``"`YG@+6><YZ3_L``8WY""
M4/^_`&C_L@`H_[$`(/^^`&#_MP!0_[8`2/^U`$#_M``X_[,`,-^9@4B.!```
M`R#X"=^2@%B.!```WYF!2`!`B"4#(/@)9E(@+-^$@%B2(P"X9(1AT`)`R"4#
M(/@)H$,`N1!```<D`P`Q@$0``!2#``7?F8#(@$(``1!```7?F8%(WYF`R`,@
M^`D`````WYF!2`,@^`F.!```WX6`6-^9@D`D!P`+)`8``62E8]`#(/@)`$`@
M)11``"K?EH`XWYF!2`,@^`F.!```WX6`6-^9@D`D!P`#)`8``62E8]@#(/@)
M`$`@)11``&D`0(@EWYF!2`,@^`F.!```WX6`6-^9@D`D!P`#)`8``62E8^@#
M(/@)`$`@)1!``(D`0(@EWX2`6`)`R"4#(/@)9(1A>!!``'$`0)@EWYF!2`,@
M^`F.!```WB,`$`)@,"7<90``WYF",`,@^`D`0"`E$```>`````#<0@`0/!,`
M(-Q5`"C?GH`X)!$``0+`H"4F<P0`CL*T`(X$```"(A`J)B;__Q!```PF-___
MWYF!2`,@^`FOI@``CZ8``-^9@L```#@E`J`H)0,@^`D`0"`E%$``!P!`&"6.
M@K0`)$+__Q17_[W?F8%($```*"01``'?Q+/X`!$0^`""$"W<9```W$@``(R"
M``PD!00``%,0)!1%``G?F8%(W(4`$-^9@M@#(/@)`0`@)11`_^R.@K0`$`#_
MV"8Q``&.!```_Z@```,@^`G_HP`(WZ,`"-^9@2C<90``)`<``@``,"4#(/@)
M`$`@)=^H```0`/_L`$`H)=^9@4@#(/@))C$``=^9@T`"H"@E`R#X"0!`("6.
M@K0``B(0*A1`__:.!```$`#_CM^9@4C?F8%(`R#X"8X$``#>(P`0WX:`6-QE
M``#?F8(P`$`@)0,@^`EDQF/@WB(`$-Q"``",0@`,``(5@C!"``$00/^(WYF!
M2`,@^`F.!```WB,`$-^9@K#<90```R#X"0!`("40`/^`WYF!2-^9@(@#(/@)
M`````(X$``#?F8%($$``-0!`F"4#(/@)`````-XC`!#?F8(PW&4```!`("4#
M(/@)`F`P)=^9@7`#(/@)`F`@)=^9@4@#(/@)C@0``(X$``#?F8%(`R#X"0!`
MB"7?A8!8WYF#&"0&``%DI6/P`R#X"0!`("7?AH!8WYF",&3&9`@`0"@E`R#X
M"0(@("6.!```WYF!2`,@^`G?D(`XWX2`6`)`R"5DA&%H`R#X":!``+D"`(@E
M%$``$OX"M`C?@H`XWYF`T`,@^`G<1+/X%$``#/X"M`C?A(!8WYF"^`,@^`ED
MA&00`R#X"0````#?@X`XW&2S^-XC`!`0`/]4W(8``-^9@7C>)+0(`R#X"20%
M`<``0#@E)`(`$1#B``PDX@`!+$(``A1```K?OP!HWX*`.-^$@%C<0K/XWB:T
M"-Q%``#?F8+X`R#X"62$9#C?OP!HW[X`8-^\`%C?MP!0W[8`2-^U`$#?M``X
MW[,`,-^R`"C?L0`@W[``&`/@``AGO0!P9[W_X/^\`!`\'``"`YG@+6><XPS?
MF8#8_[\`&/^Q``C_L````R#X"0"`@"7?F8#@`R#X"0!`("7?F8"@`R#X"0!`
MB"400``4W[\`&!(``!(`````@@(``!!```_?A8!8WYF"6&2E8M`#(/@)`B`@
M)18B``G?OP`8WYF`6-^\`!#?L0`(`@`@)=^P``!G.2%,`R``"&>]`"#?O``0
MW[$`"-^P```#X``(9[T`(&>]_4#_O`*P/!P``@.9X"UGG.)@WXJ!^/^_`KC_
MLP*H_[("H/^Q`IC_L`*0W4(``&2#`#C_H@*(9Z(`"&2'`'@`0"@EW&8``&1C
M``@`!D`^``8P/``&,#[\J```_*8`"!3C__ADI0`09$8"`-Q%`$#<0P!H9$(`
M"`!E&";<10`(`&48)MQ%__@`91@F``,H>``#'_H`HQ@E``,8/``#&#X41O_R
M_$,`>-R,```\#5J"``P>^@`,$7@`0Q`EWZ,`"&6M>9G<BP`@W(<`$-R(`!@`
M;1@M``(0/-R)``@`:Q@M``(0/@!#$"T`Z!@F`&D8)`!H&"8`0Q`M``DWN``)
M&+H`PS`E``:`/``0@#[?HP`0`/#`)@,,P"0`;1@M``(0/``"$#X#!\`F`&@8
M+0,#P"T``BEX``(>^@"C*"4#!<`M``P8N@`,+[@`HR@E`,5P)M^F`!@!PG`D
M`,TP+0`8P#P`&,`^`,<P+0'0<"8!QG`M`!@9>``8-OH`9A@E`<-P+0`"'[@`
M`A"Z`&(0)0"B&"8`!<@\WZ4`(``.<#P`#G`^`*TH+0`9R#X`>!@D`+"`+0`.
M-OH`>1@F``XI>`"F*"4`<!@M`&48+0`8+[@`&,"Z`+@H)=^X`"@``G@\`$40
M)@,-P"T`#W@^`$X0)``#&#P``Q@^`QG(+0!/$"8`61`M``/!>``#SOH#&<`E
M``Z'N``.<+H"#H`E`%@0+=^X`#``!3`\`+`H)@,-P"T`!C`^`*,H)``"$#P`
M`A`^`P]X+0"F*"8``L;Z`*\H+0`">7@!^'@E`*\H+0`#S[@``WBZ`R_()=^X
M`#@"&1@F`!!P/`,-P"T`#G`^`&(8)``%*#P`!2@^`P8P+0!N&"8`!<;Z`&88
M+0`%,7@`V#`E`&88+0`"Q[@``C"Z`P;`)0,X$"8`&7@\W[D`0``/>#X#+<@M
M`$40)``#&#P``Q@^`RYP+0!/$"8``\[Z`$X0+0`#<7@!V7`E`$X0+0`%S[@`
M!7"Z`R[()0,9*"8`&#`\W[@`2``&,#X##<`M`*,H)``"$#P``A`^`P]X+0"F
M*"8``L;Z`*\H+0`">7@!^'@E`*\H+0`#Q[@``WBZ`P_`)0,X&"8`&7`\W[D`
M4``.<#X#+<@M`&(8)``%*#P`!2@^`R8P+0!N&"8`!<[Z`&88+0`%,7@`V3`E
M`&88+0`"S[@``C"Z`R8P)0,&$"8`&'@\W[@`6``/>#X##<`M`$40)``#&#P`
M`Q@^`PYP+0!/$"8``\;Z`$X0+0`#<7@!V'`E`$X0+0`%=[@`!2BZ`<5P)=^E
M`&``!H`\`,XP)@"M*"T`$(`^`,,P)``"$#P``A`^`*]X+0#0,"8`SS`M``(I
M>``"?OH`KR@E``//N``#&+H#(\@E`,4P+=^C`&@`#L`\``8P/`'9<"8`!C`^
M`&T8+0`8P#X!PG`D`'"`+0`&+OH!V'`F``89>`!E&"4!T'`M`<-P+0`"'[@`
M`A"Z`&(0)=^C`'``&7@\``YP/`,BR"8`#G`^`&T8+0`/>#X#)L@D`'C`+0`.
M+OH#+\@F``X9>`!E&"4#.,@M`R/(+0`&*+H`!A^X`&4H)0!%,"8``H`\WZ(`
M>``9R#P`&<@^`$T0+0`0@#X`SC`D`$]X+0`9'OH`T#`F`!D1>`!#$"4`SS`M
M``X?N``.<+H`;A@E`,(P+=^B`(``!<`\``8P/`"C*"8`!C`^`$T0+0`8P#X`
MN2@D`%"`+0`&=OH`N"@F``81>`!.$"4`L"@M`*(H+0`9%[@`&<BZ`%D0)=^N
M`(@``W@\`&(8)@'-<"T`#W@^`&88)``%*#P`!2@^`=C`+0!O&"8`>!@M``5Q
M>``%QOH!V'`E`&X8+0`&=[@`!C"Z`<8P)=^X`)```H`\`$80)@,-P"T`$(`^
M`$40)``#&#P``Q@^`P]X+0!0$"8``\;Z`$\0+0`#>7@!^'@E`$\0+0`%?[@`
M!2BZ`>4H)=^O`)@``A`\``(0/@'M>"T!\(`M``9P/``"?OH`Q3`F``+!>``.
M<#X`PS`D`P_`)0#.,"8``W^X`!C`/``#&+H!XQ@E`-`P+=^O`*``&,`^`-@P
M+0`%D#P`HR@F`!*0/@`&R#P`HB@D`>UH+0`9R#X`LB@F`:YH+0"M:"T`&7;Z
M`!DI>`"N*"4`!2@\``4H/@&E:"T``B^X``(0N@"B$"4`8L`F`P;`)CP%;MG?
MI@"H-*7KH0`-F#P`$Y@^`,4P+0#2D"T`$W;ZWZ\`L``3,7@`SC`E`!F/N``8
MP#P`&<BZ``,8/`(YB"4!Y7@M``,8/@`8P#X`!C`\`Q+`+0`&,#X!XW@M`%$8
M)@,&P"T`;6@F`!B0/``-:#P`$I`^``UH/@`2'OH![7@M`!)I>`&C:"4`#6@\
MWZ8`N``-:#X![7@M`!//N``"$#P`$YBZ`S/()0`/@#P`Q3`M``(0/@`0@#X`
MPC`M`CD0)@!8P"8`$'%X`!`6^@'"<"4`&,`\`!C`/@`.<#P`V#`M``YP/@#.
M,"T`$L>X`!*0N@,2P"4`!I@\`!.8/@,X$";?K0#``$]X)@`3&7@`$Q;Z`!&(
M/`&E:"T`$8@^`&(8)0`/>#P!L6@M``]X/@`#&#P!KV@M``,8/@&C:"T`$(^X
M`!"`N@(PB"4`#9`\`!*0/@,1$";?K@#(`!(>^@!&,"8`&<@\`!(1>`'%<"T`
M&<@^`$,0)0`&,#P!V7`M``8P/@`"$#P!QG`M``(0/@'"<"T`$\^X`!.8N@,S
MR"4`#H`\`!"`/@(Y$";?HP#0`$UH)@`0,7@`$!;Z`!C`/`!E&"T`&,`^`,(P
M)0`-:#P`>!@M``UH/@`&,#P`;1@M``8P/@!F&"T`$G^X`!*0N@'R>"4``\`\
M`!C`/@,O,";?H@#8`,YP)@`8:7@`&#;Z`!&(/`!%$"T`$8@^`:9H)0`.<#P`
M41`M``YP/@`0C[@`#6@\`!"`N@(PB"4`3A`M``UH/M^F`.``31`M`?%H)@&C
M&"8`&<@\``*0/`#%,"T`&<@^``,8/``2D#X`V3`M``,8/@##,"T`$G%X`!(>
M^@'#<"4`&,^X`!C`N@,XR"4`#G`\`CD8)M^M`.@`#G`^`,XP+0!B$"8`#W@\
M``:`/`&E:"T`#W@^``(0/``0@#X!KV@M``(0/@&B:"T`$!EX`!`6^@!B&"4`
M`Q@\``,8/@&C:"T`$G^X`!*0N@'R>"4`#<`\`!C`/@,O$";?K@#P`!@>^@!&
M,"8`$8@\`!@1>`'%<"T`$8@^`$,0)0`&,#P!T7`M``8P/@`"$#P!QG`M``(0
M/@'"<"T`$(^X`!"`N@(PB"4`#I`\`!*0/@'Q$";?HP#X`$UH)@`2,7@`$A;Z
M`!G(/`!E&"T`&<@^`,(P)0`-:#P`>1@M``UH/@`&,#P`;1@M``8P/@!F&"T`
M&(>X`!C`N@(8@"4``Y@\`!.8/@(P,";?H@$``,YP)@`3:7@`$S;Z``]X/`!%
M$"T`#W@^`:9H)0`.<#P`3Q`M``YP/@`2?[@`#6@\`!*0N@'R>"4`3A`M``UH
M/@!-$"W?I@$(`@]H)@&C&"8`$8@\``+(/`#%,"T`$8@^``,8/``9R#X`T3`M
M``,8/@##,"T`&<%X`!D>^@,#P"4`$X^X`!.8N@(SB"4`&,`\`?$8)M^M`1``
M&,`^`-@P+0!B$"8`$(`\``:0/`&E:"T`$(`^``(0/``2D#X!L&@M``(0/@&B
M:"T`$AEX`!(6^@!B&"4``Q@\``,8/@&C:"T`&8>X`!G(N@(9@"4`#9@\`!.8
M/@(P$";?N`$8`$8P)@`3<7@`$Q;Z``]X/`,%P"T`#W@^`<)P)0`&,#P##\`M
M``8P/@`.<#P#!L`M``YP/@,.P"T`$G^X`!*0N@'R>"4`&,@\`!G(/@(/$";?
MHP$@`$UH)@`9,7@`&1;Z`!&(/`!E&"T`$8@^`,(P)0`-:#P`<1@M``UH/@`&
M,#P`;1@M``8P/@!F&"T`$X^X`!.8N@(SB"4``Y`\`!*0/@'Q$";?K@$H`!(V
M^@!8P"8`$(`\`!(1>`'%<"T`$(`^`$80)0`8P#P!T'`M`!C`/@`9A[@``A`\
M`!G(N@(9@"4!V'`M``(0/@'"<"W?I@$P`C`0)@!#&"8`#W@\``[`/`#%,"T`
M#W@^``,8/``8P#X`SS`M``,8/@##,"T`&!%X`!@>^@!#$"4`$G^X``(0/``2
MD+H!\G@E``(0/@(/&"8`PC`MWZ(!.``&R#P`;G`F`!&(/``9R#X`11`M`!&(
M/@`.<#P`&6[Z`%$0+0`.<#X`&1EX`&T8)0!.$"T`0Q`M``)P/``8C[C?H@%`
M`!C`N@(XB"4`12@M`?$0)@!&,"8`$(`\``YP/@`0@#X`!C`\``X>^@"P*"T`
M!C`^``X1>`!#$"4`IB@M`!D?N``9R+H`>1@E`*(H+3P"(\;?I@%(``/(/#1"
M[S<``A"X`!G(/@(C:"4`#W@\`,(P+0`1P#P!KF@D`CF()``%*#P`#W@^``4H
M/@#/>"T!L6@E`:]H+0`%,7@`!7[Z`,\P)0&F:"T`#C>X``YPN@#.<"4`;A@E
M`=DP)`!E&"0`9A@EWZ8!4``8P#X`PC`M``UH/``-:#X`V,`M`'@8+0`-,7@`
M#<;Z`-@P)0!F&"T`!3>X``4HN@#%*"4`!<`\`!C`/@'%,"4`#G@\`,TP)`'8
M<"0`SC`EWZX!6``#&#P!PG`M``,8/@'9R"T`V3`M``-Q>``#SOH!V7`E``W/
MN``-:+H#+<@E`+DH)0,X:"0`HR@D`*TH)=^M`6``SC`M`:)H+0`/>#X`!C`\
M``8P/@&O>"T`KR@M``9I>``&?OH!KV@E`*TH+0`#;[@``QBZ`:,8)0`#>#P`
M#W@^`R-H)0`9<#P!IF@D`R_()`&Y:"7?N0%H``4H/`,BR"T`!2@^`SC`+0&X
M:"T`!<[Z``7!>`,9P"4`!L^X``8PN@,FR"4`>1@E`R\P)`!E&"0`9A@EWZ8!
M<`&X:"T`PC`M``YP/@`-:#P`#6@^`,YP+0!N&"T`#3%X``UV^@#.,"4`9A@M
M``4WN``%*+H`Q2@E``5P/``.<#X#)3`E`!G`/`#-,"0#+L@D`-DP)=^Y`7@`
M`Q@\`R+(+0`#&#X#+W@M`,\P+0`#SOH``WEX`?EX)0`-S[@`#6BZ`RW()0"Y
M*"4#+F@D`*,H)`"M*"7?K0&``,\P+0&B:"T`&,`^``8P/``&,#X!N,`M`+@H
M+0`&:7@`!L;Z`;AH)0"M*"T``V^X``,8N@&C&"4``\`\`!C`/@,C:"4`&7@\
M`:9H)`,XR"0!N6@EW[D!B``%*#P#(L@M``4H/@,N<"T!KF@M``7.^@`%<7@!
MV7`E``;/N``&,+H#)L@E`'D8)0,X,"0`91@D`&88)=^F`9`!KF@M`,(P+0`/
M>#X`#6@\``UH/@#/>"T`;Q@M``TQ>``-?OH`SS`E`&88+0`%-[@`!2BZ`,4H
M)0`%>#P`#W@^`R4P)0`9<#P`S3`D`R_()`#9,"7?N0&8``,8/`,BR"T``Q@^
M`SC`+0#8,"T``\[Z``/!>`,9P"4`#<^X``UHN@,MR"4`N2@E`R]H)`"C*"0`
MK2@EWZT!H`#8,"T!HF@M``YP/@`&,#P`!C`^`:YP+0"N*"T`!FEX``9V^@&N
M:"4`K2@M``-ON``#&+H!HQ@E``-P/``.<#X#(V@E`!G`/`&F:"0#+L@D`;EH
M)=^Y`:@`!2@\`R+(+0`%*#X#+W@M`:]H+0`%SOH`!7EX`?EX)0`&S[@`!C"Z
M`R;()0!Y&"4#+C`D`&48)`!F&"7?I@&P`:]H+0#","T`&,`^``UH/``-:#X`
MV,`M`'@8+0`-,7@`#<;Z`-@P)0!F&"T`!3>X``4HN@#%*"4`!<`\`!C`/@,E
M,"4`&7@\`,TP)`,XR"0`V3`EW[D!N``#&#P#(L@M``,8/@,N<"T`SC`M``/.
M^@`#<7@!V7`E``W/N``-:+H#+<@E`+DH)0,X:"0`HR@D`*TH)=^M`<``SC`M
M`:)H+0`/>#X`!C`\``8P/@&O>"T`KR@M``9I>``&?OH!KV@E`*TH+0`#;[@`
M`QBZ`:,8)0`#>#P`#W@^`R-H)0`9<#P!IF@D`R_()`&Y:"7?N0'(``4H/`,B
MR"T`!2@^`SC`+0&X:"T`!<[Z``7!>`,9P"4`!L^X``8PN@,FR"4`>1@E`R\P
M)`!E&"0`9A@EWZ8!T`&X:"T`PC`M``YP/@`-:#P`#6@^`,YP+0!N&"T`#3%X
M``UV^@#.,"4`9A@M``4WN``%*+H`Q3`E``:`/``0@#X#)B@E`S!P)`"M*"0`
MKB@EWZX!V``#&#P!PG`M``,8/@'/>"T`KW@M``-V^@`#*7@`KB@E``4H/``%
M*#X!Y7@M``TON``-:+H`K6@E`,TP)0&P*"0`&<`\`,,P)``/R#P`&<@^`,4P
M)=^E`>``&9[Z`!EQ>``8P#X`HA`M`=-P)0!8$"T`#G`\`,(0+0`.<#X`3I@M
M/`)E,0`#Q[C?I@'H``,8NF1"8.L``A!X`P,8)0`3D#P`$I`^`:,H)@#","T`
MT(`M``V(/`"O*"8`$F[Z`!(Q>`#-,"4`!2@\``4H/@`&,#P`L"@M``8P/@"F
M*"T`&7^XWZ8!\``9R+H!^7@E``6`/``0@#X`;W`F`,(P+0`1B#X`T8@M`!!N
M^@'3<"8`$#%X`,TP)0`.<#P`#G`^``8P/`'1<"T`!C`^W[@!^`'&<"T`$L^X
M``,8/``2D+H#,L@E``Z8/`,"P"T``Q@^`!.8/@,#P"T!^1@F`&4H)@`3:7@`
M$Q[Z`:-H)0`%*#P`!2@^``UH/`,%*"T`#6@^`*TH+0`0C[@`$("Z`C"()0`%
MD#P`$I`^`S$8)M^F`@``$F[Z`&YP)@`/>#P`$AEX`,(P+0`/>#X`;1@E``YP
M/`#/,"T`#G`^`!-_N``#&#P`$YBZ`?-X)0#.,"T``Q@^`,,P+=^M`@@"+Q@F
M`&4H)@`9R#P`!H`\`:)H+0`9R#X`!2@\`!"`/@&Y:"T`!2@^`:5H+0`0&7@`
M$"[Z`&48)0`#&#P``Q@^`:-H+0`2Q[@`$I"Z`Q+`)0`-R#S?I0(0`!G(/@'X
M&"8`$8@\`*(H+0`1B#X`9C`F`!EQ>``9'OH`L2@M`<-P)0`0C[@`!C`\`!"`
MN@(PB"4`!C`^``YP/`"F*"T`#G`^`Q$P)M^C`A@`KB@M`,UH)@`/>#P`!9`\
M`&(8+0`/>#X`#6@\`!*0/@!O&"T`#6@^`&T8+0`2,7@`$F[Z`,TP)0`9?[@`
M!C`\`!G(N@'Y>"4`!C`^`&88+=^N`B`"+S`F`,4H)@`8P#P``X`\`<)P+0`8
MP#X`!2@\`!"`/@'8<"T`!2@^`<5P+0`0:7@`$"[Z`:5H)0`2Q[@`$I"Z`Q+`
M)0`-:#P!^"@F``UH/M^F`B@!S7`M`*,8)@`1B#P`#L@\`,(P+0`1B#X``Q@\
M`!G(/@#1,"T``Q@^`,,P+0`9*7@`&1[Z`*,H)0`%*#P`!2@^`,4P+0`0E[@`
M$("Z`E"0)0`&F#P`$Y@^`Q(8)M^M`C``$R[Z`&YP)@`/>#P`$QEX`:)H+0`/
M>#X`91@E``YP/`&O:"T`#G`^``,8/`&N:"T``Q@^`:-H+0`9A[@`&<BZ`AF`
M)0`-B#S?I0(X`!&(/@)0&"8`&,`\`*(H+0`8P#X`9C`F`!%Y>``1'OH`N"@M
M`>-X)0`3Q[@`!C`\`!.8N@,3P"4`!C`^``]X/`"F*"T`#W@^`A@P)M^C`D``
MKR@M`,UH)@`2D#P`!<@\`&(8+0`2D#X`#6@\`!G(/@!R&"T`#6@^`&T8+0`9
M,7@`&6[Z`,TP)0`1E[@`!C`\`!&(N@)1D"4`!C`^`&88+=^O`D@#$C`F`,4H
M)@`0@#P``Y@\`>)X+0`0@#X`!2@\`!.8/@'P>"T`!2@^`>5X+0`3<7@`$R[Z
M`<5P)0`9A[@`&<BZ`AF`)0`.<#P"4"@F``YP/M^F`E`![G@M`*,8)@`8P#P`
M#X@\`,(P+0`8P#X``Q@\`!&(/@#8,"T``Q@^`,,P+0`1:7@`$1[Z`:-H)0`-
M:#P`#6@^`,TP+0`3Q[@`$YBZ`Q/`)0`&R#P`&<@^`A@8)M^N`E@`;W@F`!DI
M>``9'OH`$I`\`<)P+0`2D#X`HR@E``]X/`'2<"T`#W@^``4H/`'/<"T`!2@^
M`<5P+0`1E[@`$8BZ`E&0)0`.F#P`$Y@^`Q(8)M^M`F``9C`F`!-Y>``3'OH`
M$(`\`:)H+0`0@#X!XW@E``8P/`&P:"T`!C`^``]X/`&F:"T`#W@^`:]H+0`9
MA[@`&<BZ`AF`)0`-B#P`$8@^`E`8)M^E`F@`$3;Z`&YP)@`8P#P`$1EX`*(H
M+0`8P#X`9A@E``YP/`"X*"T`#G`^``,8/`"N*"T``Q@^`*,H+0`3Q[@`$YBZ
M`Q/`)0`%R#P`&<@^`A@8)M^O`G``&3;Z`&UH)@`2D#P`&1EX`>)X+0!F&"4`
M$I`^``UH/``-:#X`$3>X`?)X+0`#&#P`$8BZ`-$P)0'M>"T``Q@^`P9P)@'C
M>"W?HP)X`<4H)@`0@#P`#V@\`&(8+0`0@#X`!2@\``UH/@`%*#X`<!@M``UV
M^@!E&"T`#2EX`*XH)0!E&"T`&7>XWZ4"@``9R+H!V7`E`*(0+0#.*"8`KW@F
M``,8/``8P#P``Q@^`$P0+0`8P#X`#W@\``,I>``#9OH`6!`M``]X/@!/$"T`
MK"@E`$40+0`"$#P``A`^_((```!I&"T`#1>X``UHN@!-$"4``Q@\``,8/@!'
M."T!R'`M`,LP+?R#``@`!S@\WZ,"B``.<#P`!C`\W4(````'.#X`#G`^``8P
M/OR'`!#\C@`8$&(`!/R&`"#?F8$8`R#X"0````#?OP*XW[P"L-^S`JC?L@*@
MW[$"F-^P`I`#X``(9[T"P&>]__#_O```/!P``@.9X"UGG,A<WYF"H/^_``@#
M(/@))`0`@#P$9T5DA",!_$0``"0$=^<`!"1X9(2KB?Q$``@\!$Q=9(1N?P`$
M('C\1``0/`00,F2$5';\1``8/`0,/62$+A\`!"$X_$0`(/Q``"C\0``PK$``
M>-^_``C?O````^``"&>]`!!GO?_`_[P`,/^Q``C_L```_[\`./^U`"C_M``@
M_[,`&/^R`!#<@P`H``80^`!#$"T``A`\/!P``@`"$#X#F>`M`$,8*V><Q]0`
M@(`E$&``!`#`B"7<@P`P9&,``?R#`##>`P`P_@(`*(X$`'@`$1=Z`&(0+?X"
M`#`0@``?9A(`."0"`$``1!`C`%$8*A!@``("(#`E`$`P)0)$("T`A1`K$$``
M`P#`H"4`E!`M`*(`,P"D$"L00``"`*:8+0"3`#/?F8$X`R#X"0````".`@!X
M)`,`0`!4$"$40P`;K@(`>-^9@%@"`"`E9SD]\`,@^`D"-(@C`F`H)=^3@%AF
M%0!X9G,]\"HB`$#?F8$X$$``&0)%&"L08``$`+(0*P)1$"T`H@`S`+(0*Q!`
M``0"(#`E`+$0+0)"`#,"(#`E`R#X"0)`("6N$0!XW[\`.-^\`##?M0`HW[0`
M(-^S`!C?L@`0W[$`"-^P```#X``(9[T`0````#008``$`+(0*P"U$"L40/_[
M`+(0*Q!```1DM`!``E00*Q1`__8`````)`8`0`)`("4#(/@))C'_P`)@R"4#
M(/@)`@`@)1``_]("@"@E9[W_P/^\`##_M0`H_[,`&/^Q``C_L```_[\`./^T
M`"#_L@`0W+(`*#P<``(`$A#Z`YG@+3!"`#]GG,84`$`8)62U`#@D0@`!`J,8
M+=^3@%@`@(@E)`3_@-RT`#"@9```*$,`.=^9@K@`H(`E`J(@+11@`&-F<SWP
M)`8`0`#",",#(/@)```H)0)@R"4#(/@)`@`@)=^9@K@D!@`X```H)0*@("4#
M(/@)```````4%CJB`@!P`!04.J("`'$`%!(ZH@(`<@`2%CJB`@!T`!(4.J("
M`'4"`"`E`!(2.@)@R"6B%`!SH@(`=@,@^`FB$@!WW@(``-^9@7```A8ZHB(`
M`-X"```"`"`E``(4.J(B``'>`@````(2.J(B``+>`@``HB(``]X"``@``A8Z
MHB(`!-X"``@``A0ZHB(`!=X"``@``A(ZHB(`!MX"``BB(@`'W@(`$``"%CJB
M(@`(W@(`$``"%#JB(@`)W@(`$``"$CJB(@`*W@(`$*(B``O>`@`8``(6.J(B
M``S>`@`8``(4.J(B``W>`@`8``(2.J(B``[>`@`8HB(`#]X"`"```A8ZHB(`
M$-X"`"```A0ZHB(`$=X"`"```A(ZHB(`$MX"`"`#(/@)HB(`$]^_`#C?O``P
MW[4`*-^T`"#?LP`8W[(`$-^Q``C?L````^``"&>]`$`D!@`X`,(P(Q``_Z8`
M`"@E`````&>]_^#_O``0/!P``@.9X"UGG,0`WX.`."0"___<>9_@_[\`&/^Q
M``@3(@`(_[```"01__]D<)_@`R#X"680__C>&0``%S'__`````#?OP`8W[P`
M$-^Q``C?L````^``"&>]`"````````````````#?F8`0`^!X)0,@^`ED&`!K
MWYF`$`/@>"4#(/@)9!@`:M^9@!`#X'@E`R#X"608`&??F8`0`^!X)0,@^`ED
M&`!FWYF`$`/@>"4#(/@)9!@`9=^9@!`#X'@E`R#X"608`&3?F8`0`^!X)0,@
M^`ED&`!CWYF`$`/@>"4#(/@)9!@`8M^9@!`#X'@E`R#X"608`&'?F8`0`^!X
M)0,@^`ED&`!?WYF`$`/@>"4#(/@)9!@`7M^9@!`#X'@E`R#X"608`%W?F8`0
M`^!X)0,@^`ED&`!<WYF`$`/@>"4#(/@)9!@`6]^9@!`#X'@E`R#X"608`%K?
MF8`0`^!X)0,@^`ED&`!9WYF`$`/@>"4#(/@)9!@`6-^9@!`#X'@E`R#X"608
M`%??F8`0`^!X)0,@^`ED&`!6WYF`$`/@>"4#(/@)9!@`5=^9@!`#X'@E`R#X
M"608`%3?F8`0`^!X)0,@^`ED&`!3WYF`$`/@>"4#(/@)9!@`4M^9@!`#X'@E
M`R#X"608`%'?F8`0`^!X)0,@^`ED&`!/WYF`$`/@>"4#(/@)9!@`3M^9@!`#
MX'@E`R#X"608`$W?F8`0`^!X)0,@^`ED&`!+WYF`$`/@>"4#(/@)9!@`2M^9
M@!`#X'@E`R#X"608`$G?F8`0`^!X)0,@^`ED&`!(WYF`$`/@>"4#(/@)9!@`
M1]^9@!`#X'@E`R#X"608`$;?F8`0`^!X)0,@^`ED&`!%WYF`$`/@>"4#(/@)
M9!@`0]^9@!`#X'@E`R#X"608`$+?F8`0`^!X)0,@^`ED&`!`WYF`$`/@>"4#
M(/@)9!@`/=^9@!`#X'@E`R#X"608`#S?F8`0`^!X)0,@^`ED&``[WYF`$`/@
M>"4#(/@)9!@`.M^9@!`#X'@E`R#X"608`#C?F8`0`^!X)0,@^`ED&``WWYF`
M$`/@>"4#(/@)9!@`-M^9@!`#X'@E`R#X"608`#7?F8`0`^!X)0,@^`ED&``R
MWYF`$`/@>"4#(/@)9!@`,=^9@!`#X'@E`R#X"608`##?F8`0`^!X)0,@^`ED
M&``OWYF`$`/@>"4#(/@)9!@`+=^9@!`#X'@E`R#X"608`"S?F8`0`^!X)0,@
M^`ED&``KWYF`$`/@>"4#(/@)9!@`*M^9@!`#X'@E`R#X"608`"G?F8`0`^!X
M)0,@^`ED&``HWYF`$`/@>"4#(/@)9!@`)]^9@!`#X'@E`R#X"608`";?F8`0
M`^!X)0,@^`ED&``EWYF`$`/@>"4#(/@)9!@`)`````````````````````!G
MO?_@_[P`$/^_`!@`````!!$``0`````#@!`E/!P``B><O[@#G^`MWYF`8`,@
M^`D`````W[P`$-^_`!@#X``(9[T`(````````````````%!!4E]435!$25(`
M``````!435!$25(``%1%35!$25(`5$5-4`````!435```````"X`````````
M+BX````````E<R\E<P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``
M````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E:2\E
M<P``````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z````````
M`"\`````````)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),
M-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140``````%!!4E]#3$5!3@````````!005)?1$5"54<`````````4$%27T-!
M0TA%`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?
M5$U01$E2`````````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M``````````!005)?0TQ%04X]````````,0````````!,1%],24)205)97U!!
M5$@`4UE35$5-```O=&UP`````%5315(`````55-%4DY!344``````````"4P
M,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`````
M``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E
M<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````$%21U8`````
M&`````````!P97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`
M````,2XP-3````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64````````M+0``
M`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R
M:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G
M(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I
M.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@
M>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN
M;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF
M("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E
M;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M
M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P
M*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L
M("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?
M<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]
M('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@
M-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T
M(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH
M)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R
M96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO
M9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T
M87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN
M;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D
M<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&
M2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I
M.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D
M=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D[
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D
M;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N
M="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@
M(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT
M9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D[
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E
M.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ
M<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L
M("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T
M(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I
M.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D[
M"GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT
M96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O
M)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@
M/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE
M(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@
M)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M
M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP
M;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U
M<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN
M960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@
M/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@
M)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@
M,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M
M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#
M;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*
M)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R
M7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q
M("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`]
M(#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T
M<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*````````````````7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("```````````'!E<FQX<VDN8P```````````````````"]L
M:6(O;&0M;75S;"UM:7!S-C0M<V8N<V\N,0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#__________P``````````________
M__\``````````````````&#0````````8.````````!@Z````````&#P````
M````8/@``````````/____\```````````````````````!DD```````````
M````````````````````````````````@`````````````````!@@```````
M`!@X````````&0````````(``````````:!8```````!HZ````````&?^```
M````````````````'=@````````>V````````0``````````)A`````````X
MK````````";H````````+K@````````O`````````"Y$````````*$@`````
M``!7]````````%A\````````6CP````````L%````````#`4````````*M``
M```````JI````````:!`````````/40```````!<4```````````````````
M``````````!@8````````&!0````````8$````````!@,````````&`@````
M````8!````````!@`````````%_P````````7^````````!?T```````````
M````````7\````````!?L````````%^@````````7Y``````````````````
M````````````7X````````!?<````````%]@````````7U``````````````
M`````%]`````````7S````````!?(````````%\0````````````````````
M`````````%\```````````````````!>\````````%[@````````````````
M``!>T````````%[`````````7K````````!>H````````%Z0````````7H``
M``````!><```````````````````7F````````!>4````````%Y`````````
M``````````!>,````````%X@````````7A````````!>`````````%WP````
M````7>````````!=T````````%W`````````7;````````!=H````````%V0
M````````78````````!=<````````%U@````````75``````````````````
M`%U`````````73````````!=(````````%T0````````70````````!<\```
M`````%S@`````````````````````````````%S0````````7,````````&C
MH$=#0SH@*$%L<&EN92`Y+C,N,"D@.2XS+C``1T-#.B`H06QP:6YE(#$P+C(N
M,5]P<F4Q*2`Q,"XR+C$@,C`R,#$R,#,````=`)````#____X````````````
M```0````'0```!\``!\PD'\``/____@``````````````%`````=````'P``
M("R0`0``____^```````````````,````!T````?```@E)`/``#____X````
M``````````!0````'0```!\``"%,D/\``/____@``````````````4`````=
M````'P``(R20`P``____^``````````````!`````!T````?```CU)!_``#_
M___X``````````````!@````'0```!\``"80D````/____@`````````````
M`!`````=````'P``)FB0`0``____^```````````````(````!T````?```F
MZ)`/``#____X`````````````"!@````'0```!\``"@P````````````````
M```````````````=````'P``*$C0_P``____^``````````````14````!T`
M```?```JI```````````````````````````````'0```!\``"K0D`$``/__
M__@``````````````"`````=````'P``+!20?P``____^```````````````
M@````!T````?```N1)`!``#____X```````````````@````'0```!\``"ZX
MD````/____@``````````````!`````=````'P``+P"0#P``____^```````
M````````,````!T````?```P%-#_``#____X`````````````('P````'0``
M`!\``#BLT/\``/____@``````````````'`````=````'P``/420`P``____
M^```````````````(````!T````?```9`)`/``#____X``````````````!0
M````'0```!\``#WPD`\``/____@``````````````L`````=````'P``5_20
M````____^```````````````$````!T````?``!8?)`_``#____X````````
M``````!`````'0```!\``%H\D#\``/____@``````````````$`````=````
M'T$````/9VYU``$````'!`,`+G-H<W1R=&%B`"Y-25!3+F%B:69L86=S`"Y-
M25!3+F]P=&EO;G,`+F1Y;F%M:6,`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR
M96PN9'EN`"YI;FET`"YT97AT`"Y-25!3+G-T=6)S`"YF:6YI`"YR;V1A=&$`
M+FEN=&5R<``N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9&%T80`N<FQD7VUA
M<``N9V]T`"YS9&%T80`N8G-S`"YC;VUM96YT`"YP9'(`+F=N=2YA='1R:6)U
M=&5S````````````````````````````````````````````````````````
M```````````````````````````````````+<```*@`````````"````````
M`C@````````".``````````8````````````````````"``````````8````
M&G````T`````"````@````````)0`````````E`````````!&```````````
M``````````@``````````0```"@````&``````````(````````#:```````
M``-H`````````@`````&```````````````(`````````!`````Q````!0``
M```````"````````!6@````````%:`````````,\````!0``````````````
M"``````````$````-P````L``````````@````````BH````````"*@`````
M```*(`````8````"``````````@`````````&````#\````#``````````(`
M```````2R````````!+(````````!+X````````````````````!````````
M``````!'````"0`````````"````````%X@````````7B`````````"`````
M!0``````````````"``````````0````4`````$`````````!@```````!@X
M````````&#@`````````:`````````````````````@``````````````%8`
M```!``````````8````````9`````````!D`````````0\``````````````
M``````$```````````````!<`````0`````````&````````7,````````!<
MP`````````/`````````````````````"```````````````:`````$`````
M````!@```````&"`````````8(``````````1`````````````````````@`
M`````````````&X````!``````````(```````!@T````````&#0````````
M/G`````````````````````0``````````````!V`````0`````````"````
M````GT````````"?0``````````<`````````````````````0``````````
M````?@````$``````````P```````9_<````````G]P`````````!```````
M``````````````0``````````````(@````!``````````,```````&?X```
M`````)_@`````````!`````````````````````(``````````````"/````
M`0`````````#```````!G_````````"?\``````````0````````````````
M````"```````````````E@````$``````````P```````:``````````H```
M````````4````````````````````!```````````````)P````!````````
M``,```````&@4````````*!0``````````@````````````````````(````
M``````````"E`````0`````0```#```````!H&````````"@8`````````-`
M````````````````````$``````````(````J@````$`````$````P``````
M`:.@````````HZ``````````"`````````````````````@`````````````
M`+$````(``````````,```````&CL````````*.H````````$'``````````
M```````````0``````````````"V`````0`````````P````````````````
M``"CJ`````````!$`````````````````````0`````````!````OP````$`
M````````````````````````````H^P````````#0```````````````````
M``0``````````````,1O___U`````````````````````````````*<L````
M`````!`````````````````````!```````````````!`````P``````````
M``````````````````"G/`````````#4`````````````````````0``````
#````
